<template>
  <div class="riskBox">
    <el-form ref="formRef" :model="state.formData" :rules="state.rules" class="register-form" label-position="top">
      <el-row :gutter="30">
        <el-col :span="12">
          <el-form-item prop="timeRange" label="技术服务期限">
            <el-date-picker
                v-model="state.formData.timeRange"
                style="width: 100%"
                type="daterange"
                range-separator="至"
                start-placeholder="开始日期"
                end-placeholder="结束日期"
                value-format="YYYY-MM-DD 00:00:00"
                size="large"
            />
          </el-form-item>
        </el-col>
        <el-col :span="6">
          <el-form-item prop="investigationPlanDate" label="计划现场勘验时间">
            <el-date-picker
                style="width: 100%"
                v-model="state.formData.investigationPlanDate"
                type="date"
                value-format="YYYY-MM-DD 00:00:00"
                placeholder="选择日期"
                size="large"
            />
          </el-form-item>
        </el-col>
      </el-row>
      <el-row>
        <el-col :span="18">
          <div style="display: flex;align-items: center">项目组成员<el-icon style="margin-left: 10px;margin-right: 4px"><InfoFilled /></el-icon><span style="font-size: 13px">金属、非金属矿及其他矿采选业：安全、机械、电气、采矿、通风、地质、水工结构</span></div>
        </el-col>
      </el-row>
      <el-table  :data="state.planPersons" :border="true" style="margin: 20px 0">
        <el-table-column label="序号" width="60" align="center" type="index"></el-table-column>
        <el-table-column label="评价组成员" prop="person.name" align="center" :show-overflow-tooltip="true"/>
        <el-table-column label="专业能力/资格证书" prop="person.certificateNo" align="center" :show-overflow-tooltip="true">
          <template #default="scope">
            {{ getCertNo(scope.row) }}
          </template>
        </el-table-column>
        <el-table-column label="承担工作" prop="work" align="center" class-name="small-padding fixed-width"></el-table-column>
        <el-table-column label="承诺后期前往现场勘验" prop="laterPromise" align="center" class-name="small-padding fixed-width">
          <template #default="scope">
            {{(scope.row.laterPromise==1 || scope.row.laterPromise==true)?'是':'否'}}
          </template>
        </el-table-column>
        <el-table-column label="未到现场勘验原因" prop="reason" align="center" class-name="small-padding fixed-width"></el-table-column>
        <el-table-column label="是否已告知" align="center" class-name="small-padding fixed-width">
          <template #default="scope">
            <el-radio-group v-model="scope.row.informed" size="large" @change="(value)=>changePerson(value,scope.row)" :disabled="projectType==='view'">
              <el-radio :label="1" size="large">是</el-radio>
              <el-radio :label="0" size="large">否</el-radio>
            </el-radio-group>
          </template>
        </el-table-column>
      </el-table>
    </el-form>
  </div>
</template>
<script setup>

import {defineEmits, defineProps, onMounted, reactive, ref, watchEffect} from "vue"
import {ElMessage} from "element-plus"
import {Search} from '@element-plus/icons-vue'
import {addWorkRecord, editWorkRecord, getWorkDetail} from "@/api/projectManage/employNoticeRcd"
import {getWorks, editWorks} from "@/api/projectManage/evaPlan"
import Cookies from "js-cookie"
const props = defineProps(['projectId'])
const emit = defineEmits(["getNextStatus"])
import { useRoute } from 'vue-router'
const route = useRoute()
const state = reactive({
  formData: {
    id: null,
    projectId: null,
    timeRange: [],
    serviceStartDate: '',
    serviceEndDate: '',
    investigationPlanDate: ''
  },
  projectId: null,
  planPersons: [],
  rules: {
    timeRange: [{required: true, message: '请选择技术服务期限', trigger: 'blur'}],
    investigationPlanDate: [{required: true, message: '请选择计划现场勘验时间', trigger: 'blur'}]
  }
})

const isAmin = ref(false)
const formRef = ref()
onMounted(() => {
  const userInfo = JSON.parse(Cookies.get('userInfo'))
  if(userInfo.identity === 0){
    isAmin.value = true;
  }
  if(props.projectId){
    getWorksList(props.projectId)
  }

});

const projectType = ref('');
const riskOpen = async (type,val) => {
  state.formData.projectId = val
  state.projectId = val
  projectType.value = route.query.type;
  // await getWorksList(val)
  if(type === 'detail' || type === 'edit' ){
    const res = await getWorkDetail({projectId: val})
    if(res.code == 200){
      state.formData = JSON.parse(JSON.stringify(res.data))
      state.formData.timeRange = [state.formData.serviceStartDate,state.formData.serviceEndDate]
    }else {
      ElMessage.warning(res.message)
    }
  }
  if(type === 'add' || type === 'clickEdit') {
    const valid = await formRef.value.validate();
    if(valid){
      if (isAmin.value) {
        ElMessage.warning("当前用户暂无权限");
        return;
      }
      state.formData.serviceStartDate = state.formData.timeRange[0]
      state.formData.serviceEndDate = state.formData.timeRange[1]
      if(type === 'add'){
        const {timeRange,id,...data} = JSON.parse(JSON.stringify(state.formData))
        const res = await addWorkRecord(data)
        if (res.code == 200) {
          ElMessage.success('保存成功')
          formRef.value.clearValidate();
          emit('getNextStatus', state.projectId);
        } else {
          ElMessage.warning(res.message)
        }

      }else if(type === 'clickEdit'){
        const {timeRange, ...data} = JSON.parse(JSON.stringify(state.formData))
        const res = await editWorkRecord(data);
        if (res.code == 200) {
          ElMessage.success('变更成功')
          formRef.value.clearValidate();
          // emit('getNextStatus', data.project.id);
        } else {
          ElMessage.warning(res.message)
        }
      }
    }
  }
}

const getWorksList = async (id) =>{
  const works = await getWorks({projectId: id ? id : props.projectId})
  if(works.code == 200){
    state.planPersons = works.data
  }else {
    ElMessage.warning(works.message)
  }
}

const getCertNo = (row)=>{
  const obj = JSON.parse(row.person.certificateNo)
  const noArr = Object.values(obj)
  return row.person.majorNames.map((item,index)=>{
    return item + '(' + noArr[index] + ')'
  }).join(',')
}

const changePerson = async (value,row)=>{
  const params = {
    id: row.id,
    projectId: row.projectId,
    informed: value
  }
  const res = await editWorks(params)
  if(res.code === 200){
    console.log(res.message)
  }else{
    ElMessage.warning(res.message)
  }
  await getWorksList(props.projectId)
}

defineExpose({
  riskOpen
});


</script>
<style scoped lang="scss">
.riskBox{
  :deep(.el-form .el-form-item__label) {
    font-size: 15px;
  }
}

</style>
